@@ -11,9 +11,10 @@
 # All configuration values have a default value; values that are commented out
 # serve to show the default value.
 
-import os
-import runpy
-import sys
+try:
+    from importlib.metadata import version as metadata_version
+except:
+    from importlib_metadata import version as metadata_version
 
 # General configuration
 # ---------------------
@@ -26,6 +27,7 @@ extensions = [
     'sphinx.ext.intersphinx',
     # Link to code in sphinx generated API docs
     "sphinx.ext.viewcode",
+    "sphinx_copybutton",
     'traits.util.trait_documenter'
 ]
 
@@ -40,14 +42,11 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'pyface'
-copyright = '2008-2022, Enthought'
+copyright = '2008-2023, Enthought'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
-version_py = os.path.join('..', '..', 'pyface', '_version.py')
-version_content = runpy.run_path(version_py)
-version = ".".join(version_content["version"].split(".", 2)[:2])
-release = version
+version = release = metadata_version("pyface")
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
@@ -215,10 +214,6 @@ autodoc_mock_imports = [
     'wx.lib.gridmovers',
     'wx.stc',
     'wx.py',
-    'IPython',
-    'IPython.frontend',
-    'IPython.frontend.wx',
-    'IPython.frontend.wx.wx_frontend',
 ]
 
 
