@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -17,9 +17,9 @@ Application class by overriding the `_run` method to perform the desired
 computation.
 """
 
-
 import argparse
-from pyface.application import Application
+
+from pyface.api import Application
 from traits.api import Str
 
 
