@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,12 +12,16 @@
 
 
 from pyface.api import ApplicationWindow, GUI, PythonShell
-from pyface.action.api import Action, MenuManager, MenuBarManager
+from pyface.i_python_shell import IPythonShell
+from traits.api import Instance
 
 
 class MainWindow(ApplicationWindow):
     """ The main application window. """
 
+    #: The PythonShell that forms the contents of the window
+    _shell = Instance(IPythonShell, allow_none=False)
+
     # 'IWindow' interface --------------------------------------------------
 
     # The size of the window.
@@ -32,11 +36,16 @@ class MainWindow(ApplicationWindow):
 
     def _create_contents(self, parent):
         """ Create the editor. """
-
-        self._shell = PythonShell(parent)
-
+        self._shell.create(parent)
         return self._shell.control
 
+    def destroy(self):
+        self._shell.destroy()
+        super().destroy()
+
+    def __shell_default(self):
+        return PythonShell()
+
 
 # Application entry point.
 if __name__ == "__main__":
