@@ -1,22 +1,23 @@
 """
 Simple demo of tasks used to develop the wx support for tasks.
 """
-# Enthought library imports.
+
 from pyface.api import GUI
 from pyface.tasks.api import Task, TaskWindow, EditorAreaPane
 
+
 class BlankTask(Task):
     """ A task that does nothing
     """
 
-    #### Task interface #######################################################
+    # Task interface -------------------------------------------------------
 
-    id = 'example.blank_task'
-    name = 'Blank'
+    id = "example.blank_task"
+    name = "Blank"
 
-    ###########################################################################
+    # ------------------------------------------------------------------------
     # 'Task' interface.
-    ###########################################################################
+    # ------------------------------------------------------------------------
 
     def create_central_pane(self):
         """ Create the central pane: the script editor.
@@ -24,6 +25,7 @@ class BlankTask(Task):
         self.editor_area = EditorAreaPane()
         return self.editor_area
 
+
 def main(argv):
     """ A simple example of using Tasks.
     """
@@ -42,6 +44,7 @@ def main(argv):
     gui.start_event_loop()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import sys
+
     main(sys.argv)
