@@ -1,5 +1,5 @@
 """Example of using a pyface Timer."""
-from __future__ import print_function
+
 
 from pyface.timer.api import Timer
 from pyface.api import GUI, ApplicationWindow
@@ -14,21 +14,21 @@ class MainWindow(ApplicationWindow):
     my_timer = Any()
 
     # Count each time the timer task executes.
-    counter = Int
+    counter = Int()
 
     def __init__(self, **traits):
         """ Creates a new application window. """
 
         # Base class constructor.
-        super(MainWindow, self).__init__(**traits)
+        super().__init__(**traits)
 
         # Add a menu bar.
         self.menu_bar_manager = MenuBarManager(
             MenuManager(
-                Action(name='Start Timer', on_perform=self._start_timer),
-                Action(name='Stop Timer', on_perform=self._stop_timer),
-                Action(name='E&xit', on_perform=self.close),
-                name = '&File',
+                Action(name="Start Timer", on_perform=self._start_timer),
+                Action(name="Stop Timer", on_perform=self._stop_timer),
+                Action(name="E&xit", on_perform=self.close),
+                name="&File",
             )
         )
 
@@ -49,7 +49,6 @@ class MainWindow(ApplicationWindow):
         if self.my_timer is not None:
             self.my_timer.Stop()
 
-
     def _timer_task(self):
         """The method run periodically by the timer."""
 
