@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -93,7 +93,7 @@ class ActionItem(ActionManagerItem):
             The parent of the new menu item control.
         menu : toolkit menu
             The menu to add the action item to.
-        controller : ActionController instance or None
+        controller : pyface.action.action_controller.ActionController  or None
             The controller to use.
         """
         if (controller is None) or controller.can_add_to_menu(self.action):
@@ -117,9 +117,9 @@ class ActionItem(ActionManagerItem):
             The parent of the new menu item control.
         tool_bar : toolkit toolbar
             The toolbar to add the action item to.
-        image_cache : ImageCache instance
+        image_cache : ImageCache
             The image cache for resized images.
-        controller : ActionController instance or None
+        controller : pyface.action.action_controller.ActionController  or None
             The controller to use.
         show_labels : bool
             Should the toolbar item show a label.
@@ -145,7 +145,7 @@ class ActionItem(ActionManagerItem):
             The parent of the new menu item control.
         tool_palette : toolkit tool palette
             The tool palette to add the action item to.
-        image_cache : ImageCache instance
+        image_cache : ImageCache
             The image cache for resized images.
         show_labels : bool
             Should the toolbar item show a label.
