@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -18,7 +18,17 @@ from .toolkit import toolkit_object
 ConfirmationDialog = toolkit_object("confirmation_dialog:ConfirmationDialog")
 
 
-def confirm(parent, message, title=None, cancel=False, default=NO):
+def confirm(
+    parent,
+    message,
+    title=None,
+    cancel=False,
+    default=NO,
+    no_label="",
+    yes_label="",
+    informative="",
+    detail="",
+):
     """ Convenience method to show a confirmation dialog.
 
     Parameters
@@ -33,6 +43,15 @@ def confirm(parent, message, title=None, cancel=False, default=NO):
         ``True`` if the dialog should contain a Cancel button.
     default : NO, YES or CANCEL
         Which button should be the default button.
+    no_label : str
+        Text to display in the NO button.
+    yes_label : str
+        Text to display in the YES button.
+    informative : str
+        Explanatory text to display along with the message.
+    detail : str
+        Further details about the message (displayed when the user clicks
+        "Show details").
     """
     if title is None:
         title = "Confirmation"
@@ -42,7 +61,11 @@ def confirm(parent, message, title=None, cancel=False, default=NO):
         message=message,
         cancel=cancel,
         default=default,
+        no_label=no_label,
+        yes_label=yes_label,
         title=title,
+        informative=informative,
+        detail=detail,
     )
 
     return dialog.open()
