@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -302,7 +302,7 @@ class DockWindowFeature(HasPrivateTraits):
 
         Parameters
         ----------
-        object : any object
+        object : Any object
             The object being dropped onto the feature image
 
         Returns
@@ -329,7 +329,7 @@ class DockWindowFeature(HasPrivateTraits):
 
         Parameters
         ----------
-        object : any object
+        object : Any object
             The object being dragged onto the feature image
 
         Returns
