@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,4 +14,11 @@ from pyface.testing.layout_widget_mixin import LayoutWidgetMixin
 
 class FieldMixin(LayoutWidgetMixin):
     """ Mixin which provides standard methods for all fields. """
-    pass
+
+    def test_text_field_alignment(self):
+        self._create_widget_control()
+
+        self.widget.alignment = 'right'
+        self.gui.process_events()
+
+        self.assertEqual(self.widget._get_control_alignment(), 'right')
