@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,7 +13,6 @@
 
 from traits.api import HasTraits, List, Str
 
-
 from pyface.i_dialog import IDialog
 from pyface.ui_traits import Image
 
@@ -37,3 +36,16 @@ class MAboutDialog(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IAboutDialog interface.
     """
+
+    #: Additional strings to be added to the dialog.
+    additions = List(Str)
+
+    #: Additional copyright strings to be added above the standard ones.
+    copyrights = List(Str)
+
+    #: The image displayed in the dialog.
+    image = Image()
+
+    def _image_default(self):
+        from .image_resource import ImageResource
+        return ImageResource('about')
