@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,19 +9,7 @@
 # Thanks for using Enthought open source!
 from . import qt_api
 
-if qt_api == "pyqt":
-    from PyQt4.QtCore import *
-
-    from PyQt4.QtCore import pyqtProperty as Property
-    from PyQt4.QtCore import pyqtSignal as Signal
-    from PyQt4.QtCore import pyqtSlot as Slot
-    from PyQt4.Qt import QCoreApplication
-    from PyQt4.Qt import Qt
-
-    __version__ = QT_VERSION_STR
-    __version_info__ = tuple(map(int, QT_VERSION_STR.split(".")))
-
-elif qt_api == "pyqt5":
+if qt_api == "pyqt5":
     from PyQt5.QtCore import *
 
     from PyQt5.QtCore import pyqtProperty as Property
