@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,17 +9,18 @@
 # Thanks for using Enthought open source!
 from . import qt_api
 
-if qt_api == "pyqt":
-    from PyQt4.QtSvg import *
-
-elif qt_api == "pyqt5":
+if qt_api == "pyqt5":
     from PyQt5.QtSvg import *
 
 elif qt_api == "pyqt6":
     from PyQt6.QtSvg import *
+    # Backwards compatibility imports
+    from PyQt6.QtSvgWidgets import *
 
 elif qt_api == "pyside6":
     from PySide6.QtSvg import *
+    # Backwards compatibility imports
+    from PySide6.QtSvgWidgets import *
 
 else:
     from PySide2.QtSvg import *
