@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -21,11 +21,11 @@ no_gui_test_assistant = GuiTestAssistant.__name__ == "Unimplemented"
 
 
 @unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
-class TestHeadingText(unittest.TestCase, GuiTestAssistant):
+class TestSplitPanel(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
         self.window = Window()
-        self.window._create()
+        self.window.create()
 
     def tearDown(self):
         if self.widget.control is not None:
@@ -41,10 +41,24 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
         GuiTestAssistant.tearDown(self)
 
     def test_lifecycle(self):
-        # test that destroy works
+        # test that create/destroy works
+        self.widget = SplitPanel(self.window.control)
+
+        self.assertIsNone(self.widget.control)
+
         with self.event_loop():
-            with self.assertWarns(PendingDeprecationWarning):
-                self.widget = SplitPanel(self.window.control)
+            self.widget.create(parent=self.window.control)
+
+        self.assertIsNotNone(self.widget.control)
+
+        with self.event_loop():
+            self.widget.destroy()
+
+    def test_one_stage_create(self):
+        # test that automatic creation works
+        with self.event_loop():
+            with self.assertWarns(DeprecationWarning):
+                self.widget = SplitPanel(self.window.control, create=True)
 
         self.assertIsNotNone(self.widget.control)
 
@@ -53,13 +67,13 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
 
     def test_two_stage_create(self):
         # test that create=False works
-        self.widget = SplitPanel(create=False)
+        with self.assertWarns(DeprecationWarning):
+            self.widget = SplitPanel(create=False)
 
         self.assertIsNone(self.widget.control)
 
         with self.event_loop():
-            self.widget.parent = self.window.control
-            self.widget.create()
+            self.widget.create(parent=self.window.control)
 
         self.assertIsNotNone(self.widget.control)
 
@@ -84,9 +98,29 @@ class TestHeadingText(unittest.TestCase, GuiTestAssistant):
 
     def test_contents(self):
         # test that contents works
+        self.widget = SplitPanel(
+            self.window.control, lhs=HeadingText, rhs=HeadingText
+        )
         with self.event_loop():
-            self.widget = SplitPanel(
-                self.window.control, lhs=HeadingText, rhs=HeadingText
-            )
+            self.widget.create()
+
+        with self.event_loop():
+            self.widget.destroy()
+
+    def test_contents_toolkit_control(self):
+        # test that toolkit control contents works
+        def create_toolkit_control(parent):
+            widget = HeadingText(parent)
+            widget.create()
+            return widget.control
+
+        self.widget = SplitPanel(
+            self.window.control,
+            lhs=create_toolkit_control,
+            rhs=create_toolkit_control,
+        )
+        with self.event_loop():
+            self.widget.create()
+
         with self.event_loop():
             self.widget.destroy()
