@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -26,6 +26,13 @@ class TestSystemMetrics(unittest.TestCase):
         height = self.metrics.screen_height
         self.assertGreaterEqual(height, 0)
 
+    def test_screen_sizes(self):
+        screens = self.metrics.screen_sizes
+        self.assertTrue(all(
+            (isinstance(screen, tuple) and len(screen) == 2)
+            for screen in screens
+        ))
+
     def test_background_color(self):
         color = self.metrics.dialog_background_color
         self.assertIn(len(color), [3, 4])
