@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,15 +15,16 @@
 
 import wx
 
-
-from traits.api import Bool, Enum, Instance, Str, Tuple
-
+from traits.api import Bool, Instance, Str, Tuple, provides
 
 from pyface.wx.aui import aui as AUI
 from pyface.image_cache import ImageCache
 from pyface.action.action_manager import ActionManager
+from pyface.action.i_tool_bar_manager import IToolBarManager
+from pyface.ui_traits import Orientation
 
 
+@provides(IToolBarManager)
 class ToolBarManager(ActionManager):
     """ A tool bar manager realizes itself in errr, a tool bar control. """
 
@@ -42,7 +43,7 @@ class ToolBarManager(ActionManager):
     name = Str("ToolBar")
 
     # The orientation of the toolbar.
-    orientation = Enum("horizontal", "vertical")
+    orientation = Orientation("horizontal")
 
     # Should we display the name of each tool bar tool under its image?
     show_tool_names = Bool(True)
