@@ -1,28 +1,25 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2007, Enthought, Inc.
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought pyface package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 
-# ETS imports
 from pyface.image_resource import ImageResource
 
 # Local import
-from grid_cell_image_renderer import GridCellImageRenderer
+from .grid_cell_image_renderer import GridCellImageRenderer
+
 
 class EditImageRenderer(GridCellImageRenderer):
-    image = ImageResource('table_edit')
+    image = ImageResource("table_edit")
 
     def __init__(self, **kw):
-        super(EditImageRenderer, self).__init__(self, **kw)
+        super().__init__(self, **kw)
 
     def get_image_for_cell(self, grid, row, col):
         """ returns the image resource for the table_edit bitmap """
@@ -32,7 +29,7 @@ class EditImageRenderer(GridCellImageRenderer):
 
         obj = grid.GetTable().model.get_rows_drag_value([row])[0]
 
-        if (not hasattr(obj, 'editable')) or obj.editable:
+        if (not hasattr(obj, "editable")) or obj.editable:
             return self.image
         return None
 
