@@ -1,5 +1,5 @@
 # (C) Copyright 2007 Riverbank Computing Limited
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -36,3 +36,7 @@ toolkit_object = Toolkit("pyface", "wx", "pyface.ui.wx")
 if ui_handler is None:
     # Tell the traits notification handlers to use this UI handler
     set_ui_handler(GUI.invoke_later)
+
+# Fix for broken Pycrust introspect module.  Imported to patch pycrust.
+# CJW: is this still needed? Has been in for years.
+from pyface.util import fix_introspect_bug  # noqa: F401, E402
