@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -89,18 +89,26 @@ class TreeViewer(ContentViewer):
         specifies the size of the label images (if any) displayed in the tree.
 
         """
-        create = traits.pop('create', True)
+        create = traits.pop('create', None)
 
         # Base class constructors.
         super().__init__(parent=parent, _image_size=image_size, **traits)
 
         if create:
+            # Create the widget's toolkit-specific control.
             self.create()
             warnings.warn(
                 "automatic widget creation is deprecated and will be removed "
-                "in a future Pyface version, use create=False and explicitly "
-                "call create() for future behaviour",
-                PendingDeprecationWarning,
+                "in a future Pyface version, code should not pass the create "
+                "parameter and should instead call create() explicitly",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        elif create is not None:
+            warnings.warn(
+                "setting create=False is no longer required",
+                DeprecationWarning,
+                stacklevel=2,
             )
 
     def _create_control(self, parent):
