@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -52,7 +52,7 @@ class Wizard(MWizard, Dialog):
     def _create_dialog_area(self, parent):
         """ Creates the main content of the dialog. """
 
-        self._layered_panel = panel = LayeredPanel(parent=parent, create=False)
+        self._layered_panel = panel = LayeredPanel(parent=parent)
         panel.create()
         # fixme: Specific size?
         panel.control.SetSize((100, 200))
