@@ -1,18 +1,27 @@
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ An item in a Perspective contents list. """
 
 
-# Enthought library imports.
 from traits.api import Enum, Float, HasTraits, provides, Str
 
-# Local imports.
-from i_perspective_item import IPerspectiveItem
+
+from .i_perspective_item import IPerspectiveItem
 
 
 @provides(IPerspectiveItem)
 class PerspectiveItem(HasTraits):
     """ An item in a Perspective contents list. """
+
     # The Id of the view to display in the perspective.
-    id = Str
+    id = Str()
 
     # The position of the view relative to the item specified in the
     # 'relative_to' trait.
@@ -26,12 +35,12 @@ class PerspectiveItem(HasTraits):
     # If the position is specified as 'with' you must specify a 'relative_to'
     # item other than the editor area (i.e., you cannot position a view 'with'
     # the editor area).
-    position = Enum('left', 'top', 'bottom', 'right', 'with')
+    position = Enum("left", "top", "bottom", "right", "with")
 
     # The Id of the view to position relative to. If this is not specified
     # (or if no view exists with this Id) then the view will be placed relative
     # to the editor area.
-    relative_to = Str
+    relative_to = Str()
 
     # The width of the item (as a fraction of the window width).
     #
@@ -50,6 +59,4 @@ class PerspectiveItem(HasTraits):
     height = Float(-1)
 
     # The style of the dock control created.
-    style_hint = Enum('tab', 'vertical', 'horizontal', 'fixed')
-
-#### EOF ######################################################################
+    style_hint = Enum("tab", "vertical", "horizontal", "fixed")
