@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -156,7 +156,7 @@ class WorkbenchWindow(ApplicationWindow):
         self.opening = event = Vetoable()
         if not event.veto:
             if self.control is None:
-                self._create()
+                self.create()
 
             self.show(True)
 
